<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Cohort selection form for coupon generator
 *
 * File         selectcohorts.php
 * Encoding     UTF-8
 *
 * @package     block_coupon
 *
 * @copyright   Sebsoft.nl
 * @author      Menno de Ridder <menno@sebsoft.nl>
 * @author      R.J. van Dongen <rogier@sebsoft.nl>
 * @license     http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace block_coupon\forms\coupon\generator;

defined('MOODLE_INTERNAL') || die();

use block_coupon\helper;
require_once($CFG->libdir . '/formslib.php');

/**
 * block_coupon\forms\coupon\generator\selectcohorts
 *
 * @package     block_coupon
 *
 * @copyright   Sebsoft.nl
 * @author      Menno de Ridder <menno@sebsoft.nl>
 * @author      R.J. van Dongen <rogier@sebsoft.nl>
 * @license     http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class selectcohorts extends \moodleform {

    /**
     * form definition
     */
    public function definition() {
        $mform = & $this->_form;

        $multiselect = true;
        if (!empty($this->_customdata['cohortmultiselect'])) {
            $multiselect = (bool)$this->_customdata['cohortmultiselect'];
        }

        $mform->addElement('header', 'header', get_string('heading:info', 'block_coupon'));
        if (!$strinfo = get_config('block_coupon', 'info_coupon_cohorts')) {
            $strinfo = get_string('missing_config_info', 'block_coupon');
        }
        $mform->addElement('static', 'info', '', $strinfo);
        $mform->addElement('header', 'header', get_string('heading:input_cohorts', 'block_coupon'));

        // First we'll get some useful info.
        $cohorts = helper::get_cohorts();

        // And create data for multiselect.
        $arrcohortselect = array();
        foreach ($cohorts as $cohort) {
            $arrcohortselect[$cohort->id] = $cohort->name;
        }

        $attributes = array('size' => min(20, count($arrcohortselect)));
        // Cohort id.
        $selectcohorts = &$mform->addElement('select', 'coupon_cohorts',
                get_string('label:coupon_cohorts', 'block_coupon'), $arrcohortselect, $attributes);
        $selectcohorts->setMultiple($multiselect);
        $mform->addRule('coupon_cohorts', get_string('error:required', 'block_coupon'), 'required', null, 'client');
        $mform->addHelpButton('coupon_cohorts', 'label:coupon_cohorts', 'block_coupon');

        $this->add_action_buttons(true, get_string('button:next', 'block_coupon'));
    }

}